@@ -17,9 +17,6 @@ class Migration(models.Model):
     current_label = models.CharField(max_length=100, null=True, blank=True)
     messages_cnt = models.IntegerField(default=0)
     last_uid = models.IntegerField(default=0)
-    
-    class Meta:
-        unique_together = ('from_email', 'to_username')
 
 class Label(models.Model):
     migration = models.ForeignKey('Migration', related_name='labels')
