@@ -2,12 +2,19 @@
 
 from django.shortcuts import render_to_response, redirect, get_object_or_404
 from django.views.decorators.csrf import csrf_exempt
-from django.http import HttpResponse
+from django.http import HttpResponse, HttpResponseForbidden
 from django.utils import simplejson as json
+from django.utils.http import urlquote
+from django.core.urlresolvers import reverse
+from django.contrib.auth import logout
+from django.contrib.auth.models import Permission
 
 from ProcImap.ImapMailbox import ImapMailbox
 from ProcImap.ImapMessage import maildirflags_from_imap_message
 
+from la_facebook.callbacks.default import DefaultFacebookCallback
+from la_facebook.access import OAuthAccess
+
 from .forms import MigrationForm
 from .models import Migration, Label
 from .utils.gmail2gmail import CaptchaError, ServerError, build_migration_service, get_server
@@ -16,7 +23,39 @@ from .utils.imaputf7 import imapUTF7Decode
 import datetime
 import pytils
 
+MIGRATION_FB_GROUP_ID = '175861035803947'
+assert MIGRATION_FB_GROUP_ID, "Please specify MIGRATION_FB_GROUP_ID constant in the migrate_mail/views.py!"
+
+MIGRATION_PERMISSION = Permission.objects.get(codename='add_migration')
+
+class FacebookCallback(DefaultFacebookCallback):
+
+    def handle_unauthenticated_user(self, request, user, access, token, user_data):
+        super(FacebookCallback, self).handle_unauthenticated_user(request, user, access, token, user_data)
+        # check for the required group
+        # if the group is found, grant user the permission to go on
+        access = OAuthAccess()
+        groups = access.make_api_call("json", self.FACEBOOK_GRAPH_TARGET, token, params={'fields': 'groups'})
+        user.user_permissions.clear()
+        for group in groups.get('groups', {}).get('data', []):
+            if unicode(group.get('id', '')) == unicode(MIGRATION_FB_GROUP_ID):
+                user.user_permissions.add(MIGRATION_PERMISSION)
+                break
+
+facebook_callback = FacebookCallback()
+
+def facebook_required(func):
+    def _facebook_required(request, *args, **kwargs):
+        if not request.user.is_authenticated():
+            return redirect(reverse('la_facebook_login') + '?next=%s' % urlquote(request.get_full_path()))
+        if not request.user.has_perm('migrate_mail.add_migration'):
+            logout(request)
+            return HttpResponseForbidden("You are not the one we trust.")
+        return func(request, *args, **kwargs)
+    return _facebook_required
+
 @csrf_exempt
+@facebook_required
 def index(request):
     if request.method == 'POST':
         form = MigrationForm(request.POST)
@@ -33,17 +72,20 @@ def index(request):
         'form': form,
     })
 
+@facebook_required
 def migrate(request, migration):
     migration = get_object_or_404(Migration, pk=migration)
     return render_to_response("migration.html", {
         'migration': migration,
     })
 
+@facebook_required
 def migrate_delete(request, migration):
     migration = get_object_or_404(Migration, pk=migration)
     migration.delete()
     return redirect('migrate_mail.index')
 
+@facebook_required
 def migrate_results(request, migration):
     migration = get_object_or_404(Migration, pk=migration)
     # remove labels, you aint gonna need them in future
@@ -57,6 +99,7 @@ def migrate_results(request, migration):
         'migration': migration,
     })
 
+@facebook_required
 def migrate_process(request, migration):
 
     def _sanitize_label(label):
